@@ -462,10 +462,11 @@ class If(Execute):
 
 
 class Form(Node):
-    def __init__(self, form, template_name=None, context=None, **kwargs):
+    def __init__(self, form, template_name=None, context=None, repeated_form=False, **kwargs):
         super().__init__(**kwargs)
         self._form = form
         self._context = context if context is not None else {}
+        self._repeated_form = repeated_form
         self._template_name = template_name
         self._user = None
         self._group = None
@@ -481,13 +482,13 @@ class Form(Node):
                 raise ImproperlyConfigured("From: at least one .User, .Group, .Permission has to be specified")
             task.interaction_user = self.get_user()
             task.interaction_group = self.get_group()
-            if task.data.get(f"_{self._name}_validated", None) is None:
+            if self._repeated_form or task.data.get(f"_{self._name}_validated", None) is None:
                 task.requires_interaction = True
                 self.release_lock(task)  # Release lock and stop automation until form is validated
                 return None
         return task  # Continue with validated form
 
-    def validate(self, task: models.AutomationTaskModel, request, form):
+    def is_valid(self, task: models.AutomationTaskModel, request, form):
         task.automation.data[f"_{self._name}_validated"] = request.user.id
         task.automation.save()
 
@@ -607,7 +608,6 @@ class Automation:
         self._iter[prev] = None  # Last item
         autorun = kwargs.pop("autorun", True)
         if 'automation' in kwargs:
-            autorun = False
             if isinstance(kwargs.get("automation"), models.AutomationModel):
                 self._db = kwargs.pop('automation')
             else:
@@ -621,7 +621,6 @@ class Automation:
                                "If 'automation' is given, no parameters allowed" % self.__class__.__name__
         elif 'automation_id' in kwargs:  # Attach to automation in DB
             self._db = self.model_class.objects.get(id=kwargs.pop('automation_id'))
-            autorun = False
             assert not kwargs, "Too many arguments for automation %s. " \
                                "If 'automation_id' is given, no parameters allowed" % self.__class__.__name__
         elif self.unique is True:  # Create or get singleton in DB
@@ -664,7 +663,7 @@ class Automation:
                 data=kwargs,
             )
         assert self._db is not None, "Internal error"
-        if autorun:
+        if autorun and not self.finished():
             self.run()
 
     def _create_model_properties(self, kwargs):
