@@ -18,10 +18,9 @@ logger = getLogger(__name__)
 
 
 def get_automation_class(dotted_name):
-    components = dotted_name.split('.')
-    cls = __import__(components[0])
-    for path in components[1:]:
-        cls = getattr(cls, path)
+    components = dotted_name.rsplit('.',1)
+    cls = __import__(components[0], fromlist=[components[-1]])
+    cls = getattr(cls, components[-1])
     return cls
 
 
@@ -66,6 +65,10 @@ class AutomationModel(models.Model):
             self._automation_class = get_automation_class(self.automation_class)
         return self._automation_class
 
+    @property
+    def instance(self):
+        return self.get_automation_class()(automation=self)
+
     @classmethod
     def run(cls, timestamp=None):
         if timestamp is None:
@@ -76,7 +79,7 @@ class AutomationModel(models.Model):
 
         for automation in automations:
             klass = import_string(automation.automation_class)
-            instance = klass(automation_id=automation.id)
+            instance = klass(automation_id=automation.id, autorun=False)
             logger.info(f"Running automation {automation.automation_class}")
             try:
                 instance.run()
@@ -170,8 +173,7 @@ class AutomationTaskModel(models.Model):
         return users
 
     def get_node(self):
-        cls = self.automation.get_automation_class()
-        instance = cls(automation=self.automation)
+        instance = self.automation.instance
         return getattr(instance, self.status)
 
     @classmethod
