@@ -9,6 +9,7 @@ from django.http import Http404
 from django.shortcuts import get_object_or_404, redirect
 from django.urls import reverse
 from django.utils.timezone import now
+from django.utils.translation import gettext as _
 from django.views.generic import TemplateView, FormView
 from django.forms import BaseForm
 
@@ -21,8 +22,7 @@ class AutomationMixin:
 
     def get_automation_instance(self, task):
         if self._automation_instance is None or self._task_id != task.id:
-            cls = task.automation.get_automation_class()
-            self._automation_instance = cls(automation=task.automation)
+            self._automation_instance = task.automation.instance
             self._task_id = task.id
         return self._automation_instance
 
@@ -65,7 +65,7 @@ class TaskView(LoginRequiredMixin, AutomationMixin, FormView):
         return context
 
     def form_valid(self, form):
-        self.node.validate(self.task, self.request, form)
+        self.node.is_valid(self.task, self.request, form)
         if self.node._run:
             self.node._automation.run(self.task.previous, self.node)
         if hasattr(self.node, "_success_url"):
@@ -95,19 +95,29 @@ class TaskDashboardView(UserIsStaff, TemplateView):
     def get_context_data(self, **kwargs):
         days = self.request.GET.get("history", "")
         days = int(days) if days.isnumeric() else 30
-        qs = models.AutomationModel.objects.filter(created__gt=now()-datetime.timedelta(days=days))
+        qs = models.AutomationModel.objects.filter(created__gt=now()-datetime.timedelta(days=days))\
+            .order_by("-created")
         automations = []
         for item in qs.order_by("automation_class").values("automation_class").distinct():
-            automation = models.get_automation_class(item['automation_class'])
             qs_filtered = qs.filter(**item)
-            dashboard = (automation.get_dashboard_context(qs_filtered)
-                         if hasattr(automation, "get_dashboard_context") else dict())
+            try:
+                automation = models.get_automation_class(item['automation_class'])
+                verbose_name = automation.get_verbose_name()
+                verbose_name_plural = automation.get_verbose_name_plural()
+                dashboard_template = getattr(getattr(automation, "Meta", None),
+                                             "dashboard_template", "")
+                dashboard = (automation.get_dashboard_context(qs_filtered)
+                             if hasattr(automation, "get_dashboard_context") else dict())
+            except AttributeError:
+                verbose_name = _("Obsolete automation %s") % item['automation_class'].rsplit(".")[-1]
+                verbose_name_plural = _("Obsolete automations %s") % item['automation_class'].rsplit(".")[-1]
+                dashboard_template = ""
+                dashboard = dict()
             automations.append(dict(cls=item['automation_class'],
-                                    verbose_name=automation.get_verbose_name(),
-                                    verbose_name_plural=automation.get_verbose_name_plural(),
+                                    verbose_name=verbose_name,
+                                    verbose_name_plural=verbose_name_plural,
                                     running=qs_filtered.filter(finished=False),
                                     finished=qs_filtered.filter(finished=True),
-                                    dashboard_template= getattr(getattr(automation, "Meta", None),
-                                                                "dashboard_template", ""),
+                                    dashboard_template=dashboard_template,
                                     dashboard=dashboard))
-        return dict(automations=automations)
+        return dict(automations=automations, timespan=_("Last %d days") % days)
